pygeodesy.rhumb.aux_.RhumbAux

Package pygeodesy :: Package rhumb :: Module aux_ :: Class RhumbAux |
[frames] | no frames]

# Class RhumbAux

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
             bases.RhumbBase --+
                               |
                              RhumbAux

Class to solve the direct and inverse rhumb problems, based on Auxiliary Latitudes for accuracy near the poles.

Note: Package numpy must be installed, version 1.16 or later.

Instance Methods
__init__(self, a_earth=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, f=None, exact=True, **TMorder_name) New `RhumbAux`. |
areaux(self, **exact) Get this ellipsoid's `exact` surface area (`meter` squared). |
Inherited from `bases.RhumbBase`: `ArcDirect`, `Direct`, `Direct8`, `DirectLine`, `Inverse`, `Inverse8`, `InverseLine`, `Line`, `toStr` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
Inherited from `bases.RhumbBase`: `RAorder`, `TMorder`, `a`, `b`, `datum`, `ellipsoid`, `equatoradius`, `exact`, `f`, `f_max`, `flattening`, `polaradius` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_earth=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, f=None, exact=True, **TMorder_name) (Constructor) |
New `RhumbAux`. Arguments: `a_earth` - This rhumb's earth model (Datum, Ellipsoid, Ellipsoid2, a_f2Tuple, 2-tuple `(a, f)`) or the (equatorial) radius (`meter`, conventionally). `f` - The ellipsoid's flattening (`scalar`), required if `a_earth` is `scalar`, ignored otherwise. `exact` - If `True`, use the exact expressions for the Auxiliary Latitudes, otherwise use the Fourier series expansion (`bool`), see also property `exact`. `TMorder_name` - Optional `name=NN` (`str`) and optional keyword argument `TMorder=6`, the order of the KTransverseMercator, see property `TMorder`. Raises: `ImportError` - Package `numpy` not found or not installed, only required for area `S12` when `exact is True`. `RhumbError` - Invalid `a_earth`, `f` or `TMorder`. Overrides: object.__init__

### areaux (self, **exact) |
Get this ellipsoid's `exact` surface area (`meter` squared). Arguments: `exact` - Optional `exact` (`bool`), overriding this rhumb's `exact` setting, if `True`, use the exact expression for the authalic radius otherwise the Taylor series. Returns: The (signed?) surface area (`meter` squared). Raises: `AuxError` - If `exact=False` and `abs(flattening)` exceeds property `f_max`. Note: The area of a polygon encircling a pole can be found by adding `areaux / 2` to the sum of `S12` for each side of the polygon. See Also: The area of rhumb polygons and method auxilats.AuxLat.AuthalicRadius2.